WebViewUserScript

Struct WebViewUserScript 

pub struct WebViewUserScript {
    pub source: String,
    pub at_document_end: bool,
    pub for_main_frame_only: bool,
}
An object that represents a script that can be injected into webpages

Fields

source: String

The script source.

at_document_end: bool

Whether script should be injected at the end of a document or the start.

for_main_frame_only: bool

Whether the script should be injected into all frames or just the main frame.

Implementations

Source

impl WebViewUserScript

pub fn new(source: String) -> Self

Creates a new user script.