WebView

Struct WebView 

pub struct WebView { /* private fields */ }
A web view that can be used to load web content.

This web view won’t be displayed to the user. It is intended for use in the background.

Implementations

Source

impl WebView

pub fn new() -> Self

Creates a new web view.

pub fn load(&self, request: Request) -> Result<(), JsError>

Loads a web page in the web view.

pub fn load_blocking(&self, request: Request) -> Result<(), JsError>

Loads a web page in the web view, blocking until the page is loaded.

pub fn load_html( &self, html: &str, base_url: Option<&str>, ) -> Result<(), JsError>

Loads the given HTML content in the web view.

pub fn load_html_blocking( &self, html: &str, base_url: Option<&str>, ) -> Result<(), JsError>

Loads HTML content in the web view, blocking until the content is loaded.

pub fn wait_for_load(&self)

Blocks the current thread until the web view is loaded.

pub fn eval(&self, js: &str) -> Result<String, JsError>

Evaluates JavaScript code in the web view, blocking until the result is available.