pub struct WebViewUserScript {
pub source: String,
pub at_document_end: bool,
pub for_main_frame_only: bool,
}Expand description
An object that represents a script that can be injected into webpages
Fields
source: StringThe script source.
at_document_end: boolWhether script should be injected at the end of a document or the start.
for_main_frame_only: boolWhether the script should be injected into all frames or just the main frame.
Implementations